@@ -189,18 +189,27 @@ class Base(Controller):
             raise NotImplementedError("Choose one of {ls, update, start, stop}")
 
     @ex(
-        help="Display all available Fluidstack nodes.",
+        help="Operations to easily work with remote servers / devices",
         arguments=[
-            (['action'],{
-                "help" : "To show one of {avail, ls, start, stop}.",
+            # TODO: maybe make grabable from ec2 ls
+            (['ip'],{
+                "help" : "IP of the target server",
                 "action" : "store"
             }),
             (['-r','--remote'],{
                 "help" : "Remote path on the target server",
                 "action": "store"
             }),
-            (['-ip'],{
-                "help" : "IP of the target server",
+            (['-u','--user'],{
+                "help" : "Which user to ssh with.",
+                "action" : "store"
+            }),
+            (['--server_name','-sn'],{
+                "help" : "To give the SFTP server a name.",
+                "action" : "store"
+            }),
+            (['-i', '--identity'],{
+                "help" : "Path to the identity file to use for ssh.",
                 "action" : "store"
             }),
             (['-p','--port'],{
@@ -209,9 +218,19 @@ class Base(Controller):
             })
         ]
     )
-    def stfp(self):
-        # whatever imports
-        from ..ext.sftp_conf import sftp_exists
+    def sftp(self):
+        ip = self.app.pargs.ip
+        remote = self.app.pargs.__dict__.get('remote') or self.app.pargs.__dict__.get('r') or '/data/openpilot'
+        port = self.app.pargs.__dict__.get('port') or self.app.pargs.__dict__.get('p') or 22
+        user = self.app.pargs.__dict__.get('user') or self.app.pargs.__dict__.get('u') or 'comma'
+        server_name = self.app.pargs.__dict__.get('server_name') or self.app.pargs.__dict__.get('sn') or 'C3'
+        identity = self.app.pargs.__dict__.get('identity') or self.app.pargs.__dict__.get('i') or os.path.expanduser("~/.ssh/id_rsa")
+
+        from ..ext.sftp_conf import get_sftp_path, write_sftp
+        if not os.path.exists(get_sftp_path()):
+            write_sftp(name=server_name, ip=ip, port=port, user=user,
+                        remote=remote, key_path=identity)
+
 
     @ex(
         help="Display all available Fluidstack nodes.",
@@ -524,19 +543,6 @@ class Base(Controller):
             })
         ]
     )
-    def track(self):
-        from ..ext.tracking import tracking, initialize, test_sentry
-        ''' 'Tracks experiments by making a Sentry alert when a script finishes. '''
-        args = self.app.pargs
-        if self.app.pargs is not None:
-            tracking(args.flags, args.t, args.ns, args.p)
-
-    @ex(
-        help='Test if sentry DSN is set up correctly.'
-    )
-    def test(self):
-        from ..ext.tracking import initialize, test_sentry
-        test_sentry()
 
     @ex(
         help='All Github related operations',
