@@ -19,22 +19,22 @@ def get_public_ip():
     # data = '<html><head><title>Current IP Check</title></head><body>Current IP Address: 65.96.168.198</body></html>\r\n'
     return re.compile(r'Address: (\d+\.\d+\.\d+\.\d+)').search(data).group(1)
 
-def get_sg(sg_name: str, profile: str, sid: int):
+def get_sg(profile: str, sid: int, sg_name = None):
     
     # decide if use security group name or security group id
     if sid:
         # get relevant row from security group df
-        sg_name = list_security_groups().iloc[sid-1]['GroupName']
+        sg_name = list_security_groups().iloc[sid]['GroupName']
     else:
-        sg_name = sg_name or 'default'
+        sg_name = 'default'
     
     import boto3
     profile = profile or 'default'
 
     ec2 = boto3.session.Session(profile_name=profile, region_name='eu-west-1').client('ec2')
     resp = ec2.describe_security_groups()
-    target_sg_str = list(filter(lambda x: x['GroupName']==sg_name, resp['SecurityGroups']))
-    return target_sg_str
+    target_sg_dict = list(filter(lambda x: x['GroupName']==sg_name, resp['SecurityGroups']))
+    return target_sg_dict
 
 def check_if_aux(ip_permissions: list):
     try:
@@ -52,16 +52,16 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
 
     ip = f"{get_public_ip()}/32"
 
-    ec2 = boto3.session.Session(profile_name=profile, region_name='eu-west-1').client('ec2')
     profile = profile or 'default'
+    sid = list_security_groups().index[list_security_groups().GroupName==sg_name].tolist()[0]
+    ec2 = boto3.session.Session(profile_name=profile, region_name='eu-west-1').client('ec2')
 
-    target_sg_str = get_sg(sg_name, profile=profile)[0]
+    target_sg_dict = get_sg(sg_name=sg_name, sid=sid, profile=profile)[0]
     ec2_res = boto3.session.Session(profile_name=profile, region_name='eu-west-1').resource('ec2')
-    sg_res = ec2_res.SecurityGroup(target_sg_str['GroupId'])
+    sg_res = ec2_res.SecurityGroup(target_sg_dict['GroupId'])
 
     # loop using description to only remove Aux and not e.g. NFS or Home
     # old port-based solution
-    # permissions_to_revoke = [ s for s in sg_res.ip_permissions if s['FromPort'] in ports ]
     permissions_to_revoke = [ s for s in sg_res.ip_permissions if check_if_aux(s) ]
 
     # Removes all relevant permissions from this group (originally as `jakub`)
@@ -70,6 +70,7 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
         sg_res.revoke_ingress(IpPermissions=permissions_to_revoke)
 
     if messages=='':
+        print('Warning messages are empty. Skipping')
         descriptions = {
                 22: 'Jakub Aux SSH',
                 80: 'Web',
@@ -90,12 +91,10 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
         'IpRanges': [{'CidrIp': ip, 'Description': descriptions[ports[i]] }]}
             for i in range(len(ports)) ]
 
-    # print(ip_perms)
-
     data = ec2.authorize_security_group_ingress(
-            GroupId=target_sg_str['GroupId'],
+            GroupId=target_sg_dict['GroupId'],
             IpPermissions=ip_perms )
-    print('Ingress Successfully Set %s' % data)
+    print(f'Ingress Successfully Set {ip_perms} to {sg_name}')
 
 # lists all security groups
 def list_security_groups():
