@@ -6,10 +6,10 @@ def get_sftp_path():
     Checks if SFTP config exists.
     '''
     cwd = os.getcwd()
-    target_path = os.path.join(cwd, '.vsode/sftp.json')
+    target_path = os.path.join(cwd, '.vscode/sftp.json')
     return target_path
 
-def modify_sftp(name: str, remote: str, ip: int,
+def write_sftp(name: str, remote: str, ip: int,
                 user: str, port: int, key_path: str):
     sftp_path = get_sftp_path()
     new_config = {
@@ -20,7 +20,7 @@ def modify_sftp(name: str, remote: str, ip: int,
         "username": user,
         "remotePath": remote,
         "privateKeyPath" : key_path,
-        "uploadOnSave": true,
+        "uploadOnSave": "true",
         "watcher": {
             "files": "*.{py,.sh,.txt}"
         },
@@ -35,13 +35,14 @@ def modify_sftp(name: str, remote: str, ip: int,
         ]
     }
     if not os.path.exists(sftp_path):
-        json.write(new_config, key_path)
-
-
+        os.mkdir(os.path.join(os.getcwd(), '.vscode'))
         # create sftp
+        json.dump(new_config, open(sftp_path, 'w'))
+
     else:
         old_config = json.loads(sftp_path)
         # TODO: update values from new config
         config = {
             **new_config
-        }
\ No newline at end of file
+        }
+        json.dump(config, open(sftp_path, 'w'))
\ No newline at end of file
